@@ -16,7 +16,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  * As a special exception, if you link this library with other files to
  * produce an executable, this library does not by itself cause the
@@ -41,7 +41,7 @@ import javax.mail.Part;
  * values are correctly encoded.
  *
  * @author <a href="mailto:dog@gnu.org">Chris Burdess</a>
- * @version 1.3
+ * @version 1.4
  */
 public interface MimePart
   extends Part
@@ -159,5 +159,19 @@ public interface MimePart
   void setText(String text, String charset)
     throws MessagingException;
   
+  /**
+   * Sets the content of this message using the specified text, and with a
+   * text MIME type of the specified subtype.
+   * <p>
+   * If the string contains non US-ASCII characters, it will be encoded 
+   * using the specified charset.
+   * @param text the text content
+   * @param charset the charset to use for any encoding
+   * @param subtype the MIME text subtype (e.g. "plain", "html")
+   * @since JavaMail 1.4
+   */
+  void setText(String text, String charset, String subtype)
+    throws MessagingException;
+  
 }
 
